#
# Conditional build:
%bcond_without	apidocs		# do not build and package API docs
%bcond_without	static_libs	# don't build static libraries
%bcond_without	tests		# don't perform "make check"
%bcond_without	vala		# Vala binding

Summary:	A library for managing OS information for virtualization
Summary(pl.UTF-8):	Biblioteka do zarządzania informacjami dotyczącymi OS na potrzeby wirtualizacji
Name:		libosinfo
Version:	1.6.0
Release:	1
License:	LGPL v2+
Group:		Libraries
Source0:	https://releases.pagure.org/libosinfo/%{name}-%{version}.tar.gz
# Source0-md5:	f6d92dc26b1b641f59679e5eecb37887
URL:		https://libosinfo.org/
BuildRequires:	autoconf >= 2.61
BuildRequires:	automake >= 1:1.11.1
BuildRequires:	gettext-tools >= 0.19.8
BuildRequires:	glib2-devel >= 1:2.44
BuildRequires:	gobject-introspection-devel >= 0.10.0
BuildRequires:	gtk-doc >= 1.10
BuildRequires:	libsoup-devel >= 2.4
BuildRequires:	libtool >= 2:2
BuildRequires:	libxml2-devel >= 1:2.6.0
BuildRequires:	libxslt-devel >= 1.0.0
BuildRequires:	pkgconfig
%{?with_vala:BuildRequires:	vala}
Requires:	/lib/hwdata/pci.ids
Requires:	/lib/hwdata/usb.ids
Requires:	glib2 >= 1:2.44
Requires:	hwdata >= 0.243-5
Requires:	libxml2 >= 1:2.6.0
Requires:	osinfo-db >= 20180612
Suggests:	osinfo-db-tools
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
libosinfo is a library that allows virtualization provisioning tools
to determine the optimal device settings for a hypervisor/operating
system combination.

%description -l pl.UTF-8
libosinfo to biblioteka umożliwiająca narzędziom wirtualizacyjnym
określenie optymalnych ustawień dla danej kombinacji hipernadzorcy i
systemu operacyjnego.

%package devel
Summary:	Header files for libosinfo library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki libosinfo
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	glib2-devel >= 1:2.44

%description devel
Header files for libosinfo library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki libosinfo.

%package static
Summary:	Static libosinfo library
Summary(pl.UTF-8):	Statyczna biblioteka libosinfo
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static libosinfo library.

%description static -l pl.UTF-8
Statyczna biblioteka libosinfo.

%package apidocs
Summary:	libosinfo API documentation
Summary(pl.UTF-8):	Dokumentacja API biblioteki libosinfo
Group:		Documentation
Requires:	gtk-doc-common
%if "%{_rpmversion}" >= "5"
BuildArch:	noarch
%endif

%description apidocs
API documentation for libosinfo library.

%description apidocs -l pl.UTF-8
Dokumentacja API biblioteki libosinfo.

%package -n vala-libosinfo
Summary:	libosinfo API for Vala language
Summary(pl.UTF-8):	API libosinfo dla języka Vala
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}
%if "%{_rpmversion}" >= "5"
BuildArch:	noarch
%endif

%description -n vala-libosinfo
libosinfo API for Vala language.

%description -n vala-libosinfo -l pl.UTF-8
API libosinfo dla języka Vala.

%prep
%setup -q

%build
%{__libtoolize}
%{__aclocal} -I m4
%{__autoconf}
%{__autoheader}
%{__automake}
%configure \
	%{__enable_disable apidocs gtk-doc} \
	--disable-silent-rules \
	%{?with_static_libs:--enable-static} \
	%{__enable_disable tests} \
	%{!?with_vala:--disable-vala} \
	--with-html-dir=%{_gtkdocdir} \
	--with-pci-ids-path=/lib/hwdata/pci.ids \
	--with-usb-ids-path=/lib/hwdata/usb.ids
%{__make}

%if %{with tests}
%{__make} check
%endif

%install
rm -rf $RPM_BUILD_ROOT

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

%{__rm} $RPM_BUILD_ROOT%{_libdir}/*.la

# not yet supported by glibc
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/{bal,ilo,kw@kkcor,kw@uccor,tw,wba}
# a copy of kw
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/kw_GB

%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files -f %{name}.lang
%defattr(644,root,root,755)
%doc AUTHORS ChangeLog NEWS README
%attr(755,root,root) %{_bindir}/osinfo-detect
%attr(755,root,root) %{_bindir}/osinfo-install-script
%attr(755,root,root) %{_bindir}/osinfo-query
%attr(755,root,root) %{_libdir}/libosinfo-1.0.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libosinfo-1.0.so.0
%{_libdir}/girepository-1.0/Libosinfo-1.0.typelib
%{_mandir}/man1/osinfo-detect.1*
%{_mandir}/man1/osinfo-install-script.1*
%{_mandir}/man1/osinfo-query.1*

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libosinfo-1.0.so
%{_datadir}/gir-1.0/Libosinfo-1.0.gir
%{_includedir}/libosinfo-1.0
%{_pkgconfigdir}/libosinfo-1.0.pc

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libosinfo-1.0.a
%endif

%if %{with apidocs}
%files apidocs
%defattr(644,root,root,755)
%{_gtkdocdir}/Libosinfo
%endif

%if %{with vala}
%files -n vala-libosinfo
%defattr(644,root,root,755)
%{_datadir}/vala/vapi/libosinfo-1.0.vapi
%endif
%changelog
* Fri Oct 11 2019 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/libosinfo.git;a=log;h=master

* Fri Oct 11 2019 Jakub Bogusz <qboosh@pld-linux.org> a06ba52
- updated to 1.6.0

* Sun May 19 2019 Jakub Bogusz <qboosh@pld-linux.org> 1f100cb
- updated to 1.5.0

* Sun May 28 2017 Jakub Bogusz <qboosh@pld-linux.org> 38c3626
- updated URLs

* Sat Jan 14 2017 Jakub Bogusz <qboosh@pld-linux.org> ac0e5d1
- loosed osinfo-db-tools dependency to Suggests (not used by library itself)

* Sat Jan 14 2017 Marcin Banasiak <marcin.banasiak@gmail.com> e903d39
- Update to 1.0.0

* Thu Aug 04 2016 Jakub Bogusz <qboosh@pld-linux.org> 4863ed9
- updated to 0.3.1

* Fri Apr 29 2016 Elan Ruusamäe <glen@delfi.ee> f54a247
- noarch apidocs

* Mon Mar 28 2016 Elan Ruusamäe <glen@delfi.ee> 836175b
- noarch vala subpackage

* Tue Jan 12 2016 Jakub Bogusz <qboosh@pld-linux.org> 649b6e1
- actually package locales; release 2

* Mon Jan 11 2016 Jakub Bogusz <qboosh@pld-linux.org> 77280e9
- updated to 0.3.0

* Fri Jun 26 2015 Jakub Bogusz <qboosh@pld-linux.org> 7ab0f78
- updated to 0.2.12

* Tue Mar 24 2015 Elan Ruusamäe <glen@delfi.ee> 70f1896
- x32 rebuild
- release 2 (by relup.sh)

* Sun Dec 28 2014 Jan Rękorajski <baggins@pld-linux.org> bb82a0a
- updated gettext BR

* Thu Aug 21 2014 Jan Palus <atler@pld-linux.org> 8e7de27
- up to 0.2.11
- add conditional tests support
- adapterized

* Sun Mar 30 2014 Jakub Bogusz <qboosh@pld-linux.org> 472e7be
- updated to 0.2.10

* Sun Mar 09 2014 Jakub Bogusz <qboosh@pld-linux.org> 5262ae1
- updated to 0.2.9

* Thu Sep 19 2013 Jakub Bogusz <qboosh@pld-linux.org> 9f79344
- updated to 0.2.8

* Sun May 19 2013 Jakub Bogusz <qboosh@pld-linux.org> 812ae5c
- updated to 0.2.7
- removed obsolete destdir patch

* Sat Mar 23 2013 Jakub Bogusz <qboosh@pld-linux.org> bc63ea3
- updated to 0.2.6
- use system {pci,usb}.ids (from hwdata package)
- added destdir patch (fixes install in such case)

* Fri Mar 08 2013 Jakub Bogusz <qboosh@pld-linux.org> 2bb204e
- updated to 0.2.5

